toxAUC: Create longitudinal mean score line plots for PRO-CTCAE data...

Description Usage Arguments Examples

View source: R/toxAUC.R

Description

Data format should be in 'long' format, where each PRO-CTCAE item is a variable/column.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
toxAUC(
  dsn,
  id_var,
  cycle_var,
  baseline_val,
  arm_var = NA,
  cycle_limit = NA,
  y_limit = 4,
  tab_ymin = NA,
  tab_ymax = NA,
  round_dec = 2,
  overwrite_title = NA
)

Arguments

dsn

A data.frame object with PRO-CTCAE data

id_var

A character string.Name of ID variable differentiating each PRO-CTCAE survey/participant entered as a quoted string.

cycle_var

A character string. Name of variable differentiating one longitudinal/repeated. PRO-CTCAE survey from another, within an individual ID.

baseline_val

A number indicating the expected baseline cycle/time point.

arm_var

A character string. Name of arm variable differentiating treatment groups. Must be character or factor class. Overall frequencies will be reported if no arm/grouping variable is provided. Defaults to NA.

cycle_limit

A number. Limit the number of cycles to be use to calculate the AUC metrics up to and including a given cycle number. All available cycle time points are used if no cycle number is provided. Defaults to NA.

y_limit

A number. Y axis limit for plots. Defaults to 4.

tab_ymin

A number. Y axis coordinate for adjusting the vertical placement of the AUC table within the figure. Defaults to NA.

tab_ymax

A number. Y axis coordinate for adjusting the vertical placement of the AUC table within the figure. Defaults to NA.

round_dec

A number. Number of decimal places to be shown within the AUC table. Defaults to 2.

overwrite_title

A character string. Add main title to plots. Defaults to NA.

Examples

1
2
3
4
AUC=toxAUC(dsn = ProAE::tox_acute[c(1:300, 1101:1400),1:4],
id_var = "id",
cycle_var = "Cycle",
baseline_val = 1)

blakelanglais/ProAE documentation built on Dec. 19, 2021, 9:52 a.m.