Description Usage Arguments Examples
Data format should be in 'long' format, where each PRO-CTCAE item is a variable/column.
1 2 3 4 5 6 7 8 9 10 11 12 13 |
dsn |
A data.frame object with PRO-CTCAE data |
id_var |
A character string.Name of ID variable differentiating each PRO-CTCAE survey/participant entered as a quoted string. |
cycle_var |
A character string. Name of variable differentiating one longitudinal/repeated. PRO-CTCAE survey from another, within an individual ID. |
baseline_val |
A number indicating the expected baseline cycle/time point. |
arm_var |
A character string. Name of arm variable differentiating
treatment groups. Must be character or factor class. Overall frequencies
will be reported if no arm/grouping variable is provided. Defaults to
|
cycle_limit |
A number. Limit the number of cycles to be use to
calculate the AUC metrics up to and including a given cycle number.
All available cycle time points are used if no cycle number is provided.
Defaults to |
y_limit |
A number. Y axis limit for plots. Defaults to |
tab_ymin |
A number. Y axis coordinate for adjusting the vertical
placement of the AUC table within the figure. Defaults to |
tab_ymax |
A number. Y axis coordinate for adjusting the vertical
placement of the AUC table within the figure. Defaults to |
round_dec |
A number. Number of decimal places to be shown within
the AUC table. Defaults to |
overwrite_title |
A character string. Add main title to plots. Defaults
to |
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.