Data format should be in 'long' format, where each PRO-CTCAE item is a variable/column.
toxAUC(
dsn,
id_var,
cycle_var,
baseline_val,
arm_var = NA,
cycle_limit = NA,
y_limit = 4,
tab_ymin = NA,
tab_ymax = NA,
round_dec = 2,
overwrite_title = NA
)A data.frame object with PRO-CTCAE data
A character string.Name of ID variable differentiating each PRO-CTCAE survey/participant entered as a quoted string.
A character string. Name of variable differentiating one longitudinal/repeated. PRO-CTCAE survey from another, within an individual ID.
A number indicating the expected baseline cycle/time point.
A character string. Name of arm variable differentiating
treatment groups. Must be character or factor class. Overall frequencies
will be reported if no arm/grouping variable is provided. Defaults to
NA.
A number. Limit the number of cycles to be use to
calculate the AUC metrics up to and including a given cycle number.
All available cycle time points are used if no cycle number is provided.
Defaults to NA.
A number. Y axis limit for plots. Defaults to 4.
A number. Y axis coordinate for adjusting the vertical
placement of the AUC table within the figure. Defaults to NA.
A number. Y axis coordinate for adjusting the vertical
placement of the AUC table within the figure. Defaults to NA.
A number. Number of decimal places to be shown within
the AUC table. Defaults to 2.
A character string. Add main title to plots. Defaults
to NA.
# NOT RUN {
AUC=toxAUC(dsn = ProAE::tox_acute[c(1:300, 1101:1400),1:4],
id_var = "id",
cycle_var = "Cycle",
baseline_val = 1)
AUC[[1]]
# }
Run the code above in your browser using DataLab